@@ -1,9 +1,9 @@
-from ..services.hourselection.hourselectionfactory import HourselectionFactory
+from ..services.hourselection.initializers.hourselectionfactory import HourselectionFactory
 from ..services.timer.timer import Timer
 #from ..services.chargecontroller.chargecontrollerfactory import ChargeControllerFactory
 from ..services.threshold.thresholdfactory import ThresholdFactory
 from ..services.chargecontroller.chargecontrollerbase import ChargeControllerBase
-from ..services.hourselection.hoursbase import Hours
+from ..services.hourselection.initializers.hoursbase import Hours
 from ..services.prediction.prediction import Prediction
 from ..services.production.production import ProductionService
 from ..services.scheduler.scheduler import SchedulerFacade
