@@ -1,4 +1,4 @@
-from ...models.chargerstates import CHARGERSTATES
+from ...models.chargecontroller_states import ChargeControllerStates
 from .chargecontrollerbase import ChargeControllerBase
 #from custom_components.peaqev.peaqservice.chargecontroller.chargecontrollerbase import ChargeControllerBase
 
@@ -23,19 +23,17 @@ class ChargeController(ChargeControllerBase):
             threshold_stop=self._hub.threshold.stop/100
         )
 
-    def _get_status_charging(self) -> CHARGERSTATES:
+    def _get_status_charging(self) -> ChargeControllerStates:
         if self.above_stopthreshold and self._hub.totalhourlyenergy.value > 0 and self._hub.locale.data.free_charge(self._hub.locale.data) is False:
-            ret = CHARGERSTATES.Stop
+            return ChargeControllerStates.Stop
         else:
-            ret = CHARGERSTATES.Start
-        return ret
+            return ChargeControllerStates.Start
 
-    def _get_status_connected(self, charger_state=None) -> CHARGERSTATES:
+    def _get_status_connected(self, charger_state=None) -> ChargeControllerStates:
         if charger_state is not None and self._hub.sensors.carpowersensor.value < 1 and self._is_done(charger_state):
-            ret = CHARGERSTATES.Done
+            return ChargeControllerStates.Done
         else:
             if (self.below_startthreshold and self._hub.sensors.totalhourlyenergy.value != 0) or self._hub.sensors.locale.data.free_charge(self._hub.sensors.locale.data) is True:
-                ret = CHARGERSTATES.Start
+                return ChargeControllerStates.Start
             else:
-                ret = CHARGERSTATES.Stop
-        return ret
\ No newline at end of file
+                return ChargeControllerStates.Stop
\ No newline at end of file
