@@ -1,12 +1,14 @@
 import statistics as stat
 import logging
+from ....models.hourselection.hourobject import HourObject
 
 _LOGGER = logging.getLogger(__name__)
 
 
 class HourSelectionHelpers:
     
-    def create_dict(self, input: list):
+    @staticmethod
+    def create_dict(input: list):
         ret = {}
         for idx, val in enumerate(input):
             ret[idx] = val
@@ -15,12 +17,13 @@ class HourSelectionHelpers:
         elif len(ret) == 25:
             _LOGGER.debug(f"Looks like we are heading into DST. re-parsing hours")
             input.pop(2)
-            return self.create_dict(input)
+            return HourSelectionHelpers.create_dict(input)
         else:
             _LOGGER.exception(f"Could not create dictionary from pricelist: {input} with len {len(ret)}.")
             raise ValueError
 
-    def convert_none_list(self, lst: any) -> list:
+    @staticmethod
+    def convert_none_list(lst: any) -> list:
         ret = []
         if lst is None or not isinstance(lst, list):
             return ret
@@ -32,6 +35,8 @@ class HourSelectionHelpers:
         except:
             return HourSelectionHelpers._make_array_from_empty(lst)
 
+    
+
     @staticmethod
     def _try_parse(input:str, parsetype:type):
         try:
@@ -59,6 +64,34 @@ class HourSelectionHelpers:
                 pass
         return []
 
+    
+
+    @staticmethod
+    def _convert_collections(new: HourObject, index_deviation: int) -> HourObject:
+        """Converts the hourobject-collections to interim days, based on the index-deviation provided."""
+
+        def _chop_list(lst: list):
+            return [n+index_deviation for n in lst if 0 <= n+index_deviation < 24]
+        def _chop_dict(dct: dict):
+            return {key+index_deviation:value for (key,value) in dct.items() if 0 <= key+index_deviation < 24}
+        ret = HourObject([], [], {})
+        ret.nh = _chop_list(new.nh)
+        ret.ch = _chop_list(new.ch)
+        ret.dyn_ch = _chop_dict(new.dyn_ch)
+        ret.offset_dict = _chop_dict(new.offset_dict)
+        ret.pricedict = _chop_dict(new.pricedict)
+        return ret
+
+    @staticmethod
+    def _try_remove(value, collection: list|dict):
+        if isinstance(collection, dict):
+            if value in collection.keys():
+                collection.pop(value)
+        elif isinstance(collection, list):
+            if value in collection:
+                collection.remove(value)
+        return collection
+
 
 class HourSelectionCalculations:
     
